%define anolis_release 3
%define dmraid_release 3
Summary: Device-mapper RAID tool and library
Name: dmraid
Version: 1.0.0.rc16
Release: %{anolis_release}%{dist}
License: GPLv2+
URL: http://people.redhat.com/heinzm/sw/dmraid

BuildRequires: device-mapper-devel >= 1.02.02
BuildRequires: device-mapper-event-devel
BuildRequires: libselinux-devel
BuildRequires: libsepol-devel
BuildRequires: systemd-rpm-macros
BuildRequires: gcc
BuildRequires: make
Requires: device-mapper >= 1.02.02
Requires: dmraid-libs = %{version}-%{release}
Requires: kpartx
Requires: systemd
Requires(post): systemd >= 195
Recommends: dmraid-events = %{version}-%{release}
# Splitting libraries out to -libs subpackage
Conflicts: dmraid < 1.0.0.rc16
Obsoletes: dmraid < 1.0.0.rc16

Source0: https://people.redhat.com/~heinzm/sw/dmraid/src/%{name}-%{version}-%{dmraid_release}.tar.bz2
Source1: anolis-dmraid-activation
Source2: dmraid-activation.service

Patch0: 0001-fix-compilation-error.patch
Patch1: 0002-fix-dmraid-help-coredump-on-aarch64.patch

%description
DMRAID supports RAID device discovery, RAID set activation, creation,
removal, rebuild and display of properties for ATARAID/DDF1 metadata on
Linux >= 2.4 using device-mapper.

%package -n dmraid-libs
Summary: System libraries for dmraid
# Splitting libraries out to -libs subpackage
Conflicts: dmraid < 1.0.0.rc16
Obsoletes: dmraid < 1.0.0.rc16

%description -n dmraid-libs
dmraid-libs provides the system libraries for RAID device discovery,
RAID set activation and display of properties for ATARAID volumes.

%package -n dmraid-devel
Summary: Development libraries and headers for dmraid
Requires: dmraid-libs = %{version}-%{release}
Requires: sgpio

%description -n dmraid-devel
dmraid-devel provides a library interface for RAID device discovery,
RAID set activation and display of properties for ATARAID volumes.

%package -n dmraid-events
Summary: Device-mapper event tool (dmevent_tool) and DSO
Requires: dmraid-libs = %{version}-%{release}
Requires: dmraid = %{version}-%{release}
Requires: device-mapper-event
Requires: sgpio

%description -n dmraid-events
Provides a dmeventd DSO and the dmevent_tool to register devices with it
for device monitoring.  All active RAID sets should be manually registered
with dmevent_tool.

%package -n dmraid-events-logwatch
Summary: Logwatch-based email reporting for dmraid
Requires: dmraid-events = %{version}-%{release}
Requires: crontabs
Requires: logwatch

%description -n dmraid-events-logwatch
Provides device failure reporting via logwatch-based email reporting.
Device failure reporting has to be activated manually by activating the
/etc/cron.d/dmeventd-logwatch entry and by calling the dmevent_tool
(see manual page for examples) for any active RAID sets.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -n dmraid/%{version}-%{dmraid_release}/dmraid/ -p1

%build
%global _libdir /%{_lib}

%configure --enable-debug --enable-libselinux --enable-libsepol --disable-static_link --enable-led --enable-intel_led
# parallel make is broken, do not pass smp flags
make

%install
# TODO: Do we really need to create all these dirs ourselves here? Should make install do that?
# - it is necessary to create directories for logwatch files, and likely for
# others not installed by make
install -m 755 -d %{buildroot}{%{_libdir},%{_sbindir},%{_bindir},%{_libdir},%{_includedir}/dmraid/,/etc/cron.d/,/etc/logwatch/conf/services/,/etc/logwatch/scripts/services/,/var/cache/logwatch/dmeventd}
make DESTDIR=%{buildroot} install

# Provide convenience link from dmevent_tool
(cd %{buildroot}%{_sbindir} ; ln -f dmevent_tool dm_dso_reg_tool)
(cd %{buildroot}%{_mandir}/man8 ; ln -f dmevent_tool.8 dm_dso_reg_tool.8)

install -p -m 644 include/dmraid/*.h %{buildroot}%{_includedir}/dmraid/

# Install the libdmraid and libdmraid-events (for dmeventd) DSO
# Create version symlink to libdmraid.so.1 we link against
install -p -m 755 lib/libdmraid.so %{buildroot}%{_libdir}/libdmraid.so.%{version}
(cd %{buildroot}%{_libdir} ; ln -sf libdmraid.so.%{version} libdmraid.so ; ln -sf libdmraid.so.%{version} libdmraid.so.1)
install -p -m 755 lib/libdmraid-events-isw.so %{buildroot}%{_libdir}/libdmraid-events-isw.so.%{version}
(cd %{buildroot}%{_libdir} ; ln -sf libdmraid-events-isw.so.%{version} libdmraid-events-isw.so ; ln -sf libdmraid-events-isw.so.%{version} libdmraid-events-isw.so.1)

# Install logwatch config file and script for dmeventd
install -p -m 644 logwatch/dmeventd.conf %{buildroot}/etc/logwatch/conf/services/dmeventd.conf
install -p -m 755 logwatch/dmeventd %{buildroot}/etc/logwatch/scripts/services/dmeventd
install -p -m 644 logwatch/dmeventd_cronjob.txt %{buildroot}/etc/cron.d/dmeventd-logwatch
install -p -m 0700 /dev/null %{buildroot}/var/cache/logwatch/dmeventd/syslogpattern.txt

# Install systemd unit
install -d %{buildroot}%{_prefix}/lib/systemd
install -d %{buildroot}%{_unitdir}
install -p -m 755 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/anolis-dmraid-activation
install -p -m 444 %{SOURCE2} %{buildroot}%{_unitdir}/dmraid-activation.service

rm -f %{buildroot}%{_libdir}/libdmraid.a
rm -f %{buildroot}%{_prefix}/lib/libdmraid.a

%generate_compatibility_deps

%post
%systemd_post dmraid-activation.service

%preun
%systemd_preun dmraid-activation.service

%postun
%systemd_postun dmraid-activation.service

%files
%dir %{abidir}
%license LICENSE LICENSE_GPL LICENSE_LGPL
%{_mandir}/man8/dmraid*
%{_sbindir}/dmraid
%{abidir}/libdmraid-events-isw.dump
%{abidir}/libdmraid.dump
%{_prefix}/lib/systemd/anolis-dmraid-activation
%{_unitdir}/dmraid-activation.service

%files -n dmraid-libs
%license LICENSE LICENSE_GPL LICENSE_LGPL
%{_libdir}/libdmraid.so.*
%{_libdir}/libdmraid-events-isw.so.*

%files -n dmraid-devel
%doc KNOWN_BUGS TODO doc/dmraid_design.txt
%{_libdir}/libdmraid.so
%{_prefix}/lib/libdmraid.so
%{_libdir}/libdmraid-events-isw.so
%{_libdir}/device-mapper/libdmraid-events-isw.so
%{_includedir}/dmraid

%files -n dmraid-events
%{_mandir}/man8/dmevent_tool*
%{_mandir}/man8/dm_dso_reg_tool*
%{_sbindir}/dmevent_tool
%{_sbindir}/dm_dso_reg_tool

%files -n dmraid-events-logwatch
%config(noreplace) /etc/logwatch/*
%config(noreplace) /etc/cron.d/dmeventd-logwatch
%dir /var/cache/logwatch/dmeventd
%ghost /var/cache/logwatch/dmeventd/syslogpattern.txt

%files doc
%doc CHANGELOG README CREDITS

%changelog 
* Tue Feb 07 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.0.rc16-3
- Add doc package

* Mon Oct 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.0.0.rc16-2
- fix dmraid --help coredump on aarch64

* Mon Apr 11 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 1.0.0.rc16-1
- Init package from upstream v1.0.0.rc16
